pub(crate) struct CountQuery {
pub table: String,
pub filters: Vec<Filter>,
}Fields
table: Stringfilters: Vec<Filter>Trait Implementations
Sourceimpl Clone for CountQuery
impl Clone for CountQuery
Sourcefn clone(&self) -> CountQuery
fn clone(&self) -> CountQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CountQuery
impl Debug for CountQuery
Sourceimpl Default for CountQuery
impl Default for CountQuery
Sourcefn default() -> CountQuery
fn default() -> CountQuery
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CountQuery
impl<'de> Deserialize<'de> for CountQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CountQuery
impl JsonSchema for CountQuery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CountQuery
impl RefUnwindSafe for CountQuery
impl Send for CountQuery
impl Sync for CountQuery
impl Unpin for CountQuery
impl UnsafeUnpin for CountQuery
impl UnwindSafe for CountQuery